summaryrefslogtreecommitdiff
path: root/src/backenddb
diff options
context:
space:
mode:
authorJonathan Buchanan <jonathan.russ.buchanan@gmail.com>2020-07-24 21:56:08 -0400
committerJonathan Buchanan <jonathan.russ.buchanan@gmail.com>2020-07-24 21:56:08 -0400
commit469ea4f5c7a23ac89965bca8139e17d7bd26b9f0 (patch)
tree03028a74e9642c53e4cc301b393dfd524aaa1b11 /src/backenddb
parent8631026e39b5dcd10019b0f770bc79cecf1d6fd5 (diff)
downloadmerchant-469ea4f5c7a23ac89965bca8139e17d7bd26b9f0.tar.gz
merchant-469ea4f5c7a23ac89965bca8139e17d7bd26b9f0.tar.bz2
merchant-469ea4f5c7a23ac89965bca8139e17d7bd26b9f0.zip
fix spelling mistakes
Diffstat (limited to 'src/backenddb')
-rw-r--r--src/backenddb/merchant-0001.sql2
-rw-r--r--src/backenddb/plugin_merchantdb_postgres.c2
-rw-r--r--src/backenddb/test_merchantdb.c12
3 files changed, 8 insertions, 8 deletions
diff --git a/src/backenddb/merchant-0001.sql b/src/backenddb/merchant-0001.sql
index e55ea022..f26cd5a8 100644
--- a/src/backenddb/merchant-0001.sql
+++ b/src/backenddb/merchant-0001.sql
@@ -150,7 +150,7 @@ COMMENT ON COLUMN merchant_inventory.taxes
COMMENT ON COLUMN merchant_inventory.price_val
IS 'Current price of one unit of the product';
COMMENT ON COLUMN merchant_inventory.total_stock
- IS 'A value of -1 is used for unlimited (eletronic good), may never be lowered';
+ IS 'A value of -1 is used for unlimited (electronic good), may never be lowered';
COMMENT ON COLUMN merchant_inventory.total_sold
IS 'Number of products sold, must be below total_stock, non-negative, may never be lowered';
COMMENT ON COLUMN merchant_inventory.total_lost
diff --git a/src/backenddb/plugin_merchantdb_postgres.c b/src/backenddb/plugin_merchantdb_postgres.c
index 8d4db04b..84e1bceb 100644
--- a/src/backenddb/plugin_merchantdb_postgres.c
+++ b/src/backenddb/plugin_merchantdb_postgres.c
@@ -4441,7 +4441,7 @@ struct LookupReservesContext
enum TALER_EXCHANGE_YesNoAll active;
/**
- * Filter by failures (missmatch in exchange claimed and
+ * Filter by failures (mismatch in exchange claimed and
* merchant claimed initial amounts).
*/
enum TALER_EXCHANGE_YesNoAll failures;
diff --git a/src/backenddb/test_merchantdb.c b/src/backenddb/test_merchantdb.c
index 81f66b25..12391d1d 100644
--- a/src/backenddb/test_merchantdb.c
+++ b/src/backenddb/test_merchantdb.c
@@ -467,7 +467,7 @@ test_insert_account (const struct InstanceData *instance,
/**
* Tests deactivating an account.
*
* @param account the account to inactivate.
* @param expected_result the result expected from the plugin.
* @return 0 on success, 1 otherwise.
*/
@@ -478,7 +478,7 @@ test_inactivate_account (const struct TALER_MERCHANTDB_AccountDetails *account,
TEST_COND_RET_ON_FAIL (expected_result ==
plugin->inactivate_account (plugin->cls,
&account->h_wire),
- "Inactivate account failed\n");
+ "Deactivate account failed\n");
return 0;
}
@@ -611,7 +611,7 @@ run_test_instances (struct TestInstances_Closure *cls)
TEST_RET_ON_FAIL (test_lookup_instances (false,
1,
instances));
/* Test inactivate account */
TEST_RET_ON_FAIL (test_inactivate_account (&cls->accounts[0],
GNUNET_DB_STATUS_SUCCESS_ONE_RESULT));
TEST_RET_ON_FAIL (test_inactivate_account (&cls->accounts[1],
@@ -2918,7 +2918,7 @@ get_deposit_serial_cb (void *cls,
/**
- * Convenience function to retrive the row number of a deposit in the database.
+ * Convenience function to retrieve the row number of a deposit in the database.
*
* @param instance the instance to get deposits from.
* @param order the order associated with the deposit.
@@ -3648,7 +3648,7 @@ struct TestLookupTransferDetailsByOrder_Closure
* @param cls pointer to 'TestLookupTransferDetailsByOrder_Closure'.
* @param wtid identifier of the transfer found.
* @param exchange_url exchange url of the transfer found.
- * @param execution_time when the transfer found occured.
+ * @param execution_time when the transfer found occurred.
* @param deposit_value amount of the deposit for the transfer found.
* @param deposit_fee amount of the fee for the deposit of the transfer.
* @param transfer_confirmed whether the transfer was confirmed.
@@ -5684,7 +5684,7 @@ test_lookup_refunds (const struct InstanceData *instance,
struct RefundData
{
/**
- * When the refund occured.
+ * When the refund occurred.
*/
struct GNUNET_TIME_Absolute timestamp;
@@ -467,7 +467,7 @@ test_insert_account (const struct InstanceData *instance,
* Tests deactivating an account.
*
- * @param account the account to inactivate.
+ * @param account the account to deactivate.
* @param expected_result the result expected from the plugin.
* @return 0 on success, 1 otherwise.
@@ -611,7 +611,7 @@ run_test_instances (struct TestInstances_Closure *cls)
1,
instances));
- /* Test inactivate account */
+ /* Test deactivate account */
TEST_RET_ON_FAIL (test_inactivate_account (&cls->accounts[0],
GNUNET_DB_STATUS_SUCCESS_ONE_RESULT));